| Title: | Child/Child-Adult Mortality-Indexed Model Mortality Age Schedules |
|---|---|
| Description: | Model age schedules of mortality, nqx, suitable for a life table. This package implements the SVD-Comp mortality model indexed by either child or child/adult mortality. Given input value(s) of either 5q0 or (5q0, 45q15), the qx() function generates single-year 1qx or 5-year 5qx conditional age-specific probabilities of dying. See Clark (2016) <doi:10.48550/arXiv.1612.01408> and Clark (2019) <doi:10.1007/s13524-019-00785-3>. |
| Authors: | Samuel Clark [aut, cre, cph] |
| Maintainer: | Samuel Clark <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-14 07:17:11 UTC |
| Source: | https://github.com/cran/SVDMx |
Calculate expit (inverse logit)
expit(x)expit(x)
x |
A number on the real line. |
The expit of x.
expit(-5)expit(-5)
Calculate logit
logit(x)logit(x)
x |
A number in the range (0,1). |
The logit of x.
logit(0.5)logit(0.5)
An R object containing a hierarchy of lists that contain SVD-derived components, estimated model coefficients, and other parameter values necessary to generate new 1qx values using the SVD Component mortality model indexed by child/child-adult mortality implemented by the 'qx()' function. The model objects have been 'cleaned' to remove large collections of data that are not necessary to perform predictions - this dramatically reduces their size. This is the 2018 version of the models that replicates the Demography paper.
mods2018mods2018
An R list object with members:
Samuel J. Clark, [email protected]
See model development in Clark (2016) doi:10.48550/arXiv.1612.01408 and Clark (2019) doi:10.1007/s13524-019-00785-3
An R object containing a hierarchy of lists that contain SVD-derived components, estimated model coefficients, and other parameter values necessary to generate new 1qx values using the SVD Component mortality model indexed by child/child-adult mortality implemented by the 'qx()' function. The model objects have been 'cleaned' to remove large collections of data that are not necessary to perform predictions - this dramatically reduces their size. This is the 2022 version of the models that includes additional Human Mortality Database life tables available after the Demography paper was published.
mods2022mods2022
An R list object with members:
Samuel J. Clark, [email protected]
See model development in Clark (2016) doi:10.48550/arXiv.1612.01408 and Clark (2019) doi:10.1007/s13524-019-00785-3
An R object containing a hierarchy of lists that contain SVD-derived components, estimated model coefficients, and other parameter values necessary to generate new 1qx values using the SVD Component mortality model indexed by child/child-adult mortality implemented by the 'qx()' function. The model objects have been 'cleaned' to remove large collections of data that are not necessary to perform predictions - this dramatically reduces their size. This is the 2024 version of the models that includes additional Human Mortality Database life tables available after the Demography paper was published.
mods2024mods2024
An R list object with members:
Samuel J. Clark, [email protected]
See model development in Clark (2016) doi:10.48550/arXiv.1612.01408 and Clark (2019) doi:10.1007/s13524-019-00785-3
Convert 1-year life table probabilities of dying 1qx to standard five-year age groups: 0, 1-4, 5-9, etc.
q1to5(q1)q1to5(q1)
q1 |
Decimal: the input values for 1qx; either a single vector or a matrix, age x life table. |
Data frame: equivalent values for 5qx.
Samuel J. Clark, [email protected]
q1 <- qx("female",0.08,out5=FALSE) q1to5(q1)q1 <- qx("female",0.08,out5=FALSE) q1to5(q1)
Generate single-year 1qx or 5-year 5qx age-specific probabilities of dying using the SVD-Comp mortality model indexed by child mortality, 5q0, or child and adult mortality, 5q0 and 45q15.
qx( sex, cm, smooth = TRUE, outlogit = FALSE, out5 = TRUE, am = NULL, modsv = 2024 )qx( sex, cm, smooth = TRUE, outlogit = FALSE, out5 = TRUE, am = NULL, modsv = 2024 )
sex |
Character: 'female' or 'male'. |
cm |
Decimal: the input value(s) for 5q0; either a single value or a vector of values. |
smooth |
Boolean: use either smooth or raw SVD-derived components. Default is TRUE. |
outlogit |
Boolean: output either logit-scale or natural-scale nqx values. Default is FALSE. When TRUE oldest age not returned because logit(1) not defined. |
out5 |
Boolean: output either 5-year or 1-year age groups. Default is TRUE. |
am |
Optional decimal: input value(s) for 45q15; either single value or vector of values. If a vector, must have the same number of elements as cm. |
modsv |
Optional integer: specifies version of calibration models to use: 2018, 2022, or 2024. Defaults is 2024. |
Data frame: generated 1qx or 5qx values. Oldest age assumed to be 1.0. Columns labeled with input child mortality values.
Samuel J. Clark, [email protected]
Clark (2016) doi:10.48550/arXiv.1612.01408 and Clark (2019) doi:10.1007/s13524-019-00785-3
qx("female",0.05) qx("female",0.05,modsv=2022) qx("male",0.03,am=0.26) qx("male",0.03,TRUE,TRUE,TRUE,0.26) qx("male",c(0.03,0.01))qx("female",0.05) qx("female",0.05,modsv=2022) qx("male",0.03,am=0.26) qx("male",0.03,TRUE,TRUE,TRUE,0.26) qx("male",c(0.03,0.01))